/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_QSCORE_ADAPTER_H_
#define _U2_QSCORE_ADAPTER_H_

#include <U2Core/MAlignment.h>
#include <U2Core/Task.h>

namespace U2 {
	extern double QScore(const MAlignment& maTest, const MAlignment& maRef, TaskStateInfo& ti);
}

#endif //_U2_QSCORE_ADAPTER_H_
